@@ -19,7 +19,7 @@ knitr::knit_hooks$set(time_it = local({
   }
 }))
 knitr::opts_chunk$set(time_it = TRUE)
-rgl::setupKnitr()
+#rgl::setupKnitr()
 options(rmarkdown.html_vignette.check_title = FALSE)
 library(lidR)
 
